--- layout: base title: Home ---

## Introduction

Single cell RNA-seq allows us to profile the diversity of cells along a developmental time-course. However, we cannot directly observe cellular trajectories because the measurement process is destructive. Waddington-OT is designed to infer the temporal couplings of a developmental stochastic process from samples collected independently at various time-points. The temporal couplings tell us what descendants cell $x$ from time $t_i$ would give rise to at time $t_j$

## Tutorial

A practical, hands-on introduction to inferring trajectories with wot.

## Command Line

A command line interface that offers fine-grained control over all calculations.

wot optimal_transport

## Installation

#### Pip installation

Note that due to a limitation of pip, cython and numpy need to be installed prior to installing wot using the command:
`pip install numpy cython`
You can then install wot with:
`pip install wot`

### Anaconda installation

Install pot dependency:
`conda install -c conda-forge pot`
Install wot (and additional dependencies):
`pip install wot`

## Source Code

The full source code is available on Github.